| Title: | MeSH Enrichment and Semantic analyses |
|---|---|
| Description: | Provides tools for MeSH (Medical Subject Headings) enrichment and semantic similarity analysis. The package uses MeSH term annotations linked to Entrez Gene identifiers through gendoo, gene2pubmed and RBBH, enabling over-representation analysis, gene set enrichment analysis and semantic comparison of gene lists or ranked expression profiles. It implements Resnik, Schlicker, Jiang, Lin and Wang similarity methods for comparing MeSH terms, genes and gene groups across more than 70 species. |
| Authors: | Guangchuang Yu [aut, cre] |
| Maintainer: | Guangchuang Yu <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.39.1 |
| Built: | 2026-06-30 13:14:39 UTC |
| Source: | https://github.com/bioc/meshes |
MeSH term enrichment analysis
enrichMeSH( gene, MeSHDb, database = "gendoo", category = "C", pvalueCutoff = 0.05, pAdjustMethod = "BH", universe = NULL, minGSSize = 10, maxGSSize = 500, qvalueCutoff = 0.2, meshdbVersion = NULL )enrichMeSH( gene, MeSHDb, database = "gendoo", category = "C", pvalueCutoff = 0.05, pAdjustMethod = "BH", universe = NULL, minGSSize = 10, maxGSSize = 500, qvalueCutoff = 0.2, meshdbVersion = NULL )
gene |
a vector of entrez gene id |
MeSHDb |
MeSHDb |
database |
one of 'gendoo', 'gene2pubmed' or 'RBBH' |
category |
one of "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L","M", "N", "V", "Z" |
pvalueCutoff |
Cutoff value of pvalue. |
pAdjustMethod |
one of "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none" |
universe |
background genes |
minGSSize |
minimal size of genes annotated by Ontology term for testing. |
maxGSSize |
maximal size of genes annotated for testing |
qvalueCutoff |
qvalue cutoff |
meshdbVersion |
version of MeSH.db. If NULL(the default), use the latest version. |
An enrichResult instance.
Guangchuang Yu
class?enrichResult
## Not run: library(meshes) library(AnnotationHub) ah <- AnnotationHub() qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## inspect qr_hsa and select the organism-specific MeSHDb resource filepath_hsa <- qr_hsa[[1]] db <- MeSHDbi::MeSHDb(filepath_hsa) data(geneList, package="DOSE") de <- names(geneList)[1:100] x <- enrichMeSH(de, MeSHDb = db, database='gendoo', category = 'C') ## End(Not run)## Not run: library(meshes) library(AnnotationHub) ah <- AnnotationHub() qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## inspect qr_hsa and select the organism-specific MeSHDb resource filepath_hsa <- qr_hsa[[1]] db <- MeSHDbi::MeSHDb(filepath_hsa) data(geneList, package="DOSE") de <- names(geneList)[1:100] x <- enrichMeSH(de, MeSHDb = db, database='gendoo', category = 'C') ## End(Not run)
semantic similarity between two gene vector
geneSim(geneID1, geneID2 = NULL, measure = "Wang", combine = "BMA", semData)geneSim(geneID1, geneID2 = NULL, measure = "Wang", combine = "BMA", semData)
geneID1 |
gene ID vector |
geneID2 |
gene ID vector |
measure |
one of "Wang", "Resnik", "Rel", "Jiang" and "Lin" |
combine |
One of "max", "avg", "rcmax", "BMA" methods, for combining semantic similarity scores of multiple DO terms associated with gene/protein. |
semData |
gene annotation data for semantic measurement |
score matrix
Guangchuang Yu
## library(meshes) ## library(AnnotationHub) ## ah <- AnnotationHub() ## qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## ## inspect qr_hsa and select the organism-specific MeSHDb resource ## filepath_hsa <- qr_hsa[[1]] ## db <- MeSHDbi::MeSHDb(filepath_hsa) ## hsamd <- meshdata(db, category='A', computeIC=T, database="gendoo") data(hsamd) geneSim("241", "251", semData=hsamd, measure="Wang", combine="BMA")## library(meshes) ## library(AnnotationHub) ## ah <- AnnotationHub() ## qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## ## inspect qr_hsa and select the organism-specific MeSHDb resource ## filepath_hsa <- qr_hsa[[1]] ## db <- MeSHDbi::MeSHDb(filepath_hsa) ## hsamd <- meshdata(db, category='A', computeIC=T, database="gendoo") data(hsamd) geneSim("241", "251", semData=hsamd, measure="Wang", combine="BMA")
Gene Set Enrichment Analysis of MeSH
gseMeSH( geneList, MeSHDb, database = "gendoo", category = "C", nPerm = 1000, exponent = 1, minGSSize = 10, maxGSSize = 500, pvalueCutoff = 0.05, pAdjustMethod = "BH", verbose = TRUE, ... )gseMeSH( geneList, MeSHDb, database = "gendoo", category = "C", nPerm = 1000, exponent = 1, minGSSize = 10, maxGSSize = 500, pvalueCutoff = 0.05, pAdjustMethod = "BH", verbose = TRUE, ... )
geneList |
order ranked geneList |
MeSHDb |
MeSHDb |
database |
one of 'gendoo', 'gene2pubmed' or 'RBBH' |
category |
one of "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L","M", "N", "V", "Z" |
nPerm |
number of permutations. |
exponent |
weight of each step |
minGSSize |
minimal size of each geneSet for analyzing |
maxGSSize |
maximal size of genes annotated for testing |
pvalueCutoff |
pvalue Cutoff |
pAdjustMethod |
pvalue adjustment method |
verbose |
print message or not |
... |
other parameter |
gseaResult object
Yu Guangchuang
## Not run: library(meshes) library(AnnotationHub) ah <- AnnotationHub() qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## inspect qr_hsa and select the organism-specific MeSHDb resource filepath_hsa <- qr_hsa[[1]] db <- MeSHDbi::MeSHDb(filepath_hsa) data(geneList, package="DOSE") y <- gseMeSH(geneList, MeSHDb = db, database = 'gene2pubmed', category = "G") ## End(Not run)## Not run: library(meshes) library(AnnotationHub) ah <- AnnotationHub() qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## inspect qr_hsa and select the organism-specific MeSHDb resource filepath_hsa <- qr_hsa[[1]] db <- MeSHDbi::MeSHDb(filepath_hsa) data(geneList, package="DOSE") y <- gseMeSH(geneList, MeSHDb = db, database = 'gene2pubmed', category = "G") ## End(Not run)
construct annoData for semantic measurement
meshdata(MeSHDb = NULL, database, category, computeIC = FALSE)meshdata(MeSHDb = NULL, database, category, computeIC = FALSE)
MeSHDb |
MeSHDb package |
database |
one of supported database |
category |
one of supported category |
computeIC |
logical value |
a GOSemSimDATA object
Guangchuang Yu
## Not run: library(meshes) library(AnnotationHub) ah <- AnnotationHub() qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## inspect qr_hsa and select the organism-specific MeSHDb resource filepath_hsa <- qr_hsa[[1]] db <- MeSHDbi::MeSHDb(filepath_hsa) hsamd <- meshdata(db, category='A', computeIC=T, database="gendoo") ## End(Not run)## Not run: library(meshes) library(AnnotationHub) ah <- AnnotationHub() qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## inspect qr_hsa and select the organism-specific MeSHDb resource filepath_hsa <- qr_hsa[[1]] db <- MeSHDbi::MeSHDb(filepath_hsa) hsamd <- meshdata(db, category='A', computeIC=T, database="gendoo") ## End(Not run)
semantic similarity between two MeSH term vectors
meshSim(meshID1, meshID2, measure = "Wang", semData)meshSim(meshID1, meshID2, measure = "Wang", semData)
meshID1 |
MeSH term vector |
meshID2 |
MeSH term vector |
measure |
one of "Wang", "Resnik", "Rel", "Jiang" and "Lin" |
semData |
annotation data for semantic measurement, output by meshdata function |
score matrix
Guangchuang Yu https://guangchuangyu.github.io
## library(meshes) ## library(AnnotationHub) ## ah <- AnnotationHub() ## qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## ## inspect qr_hsa and select the organism-specific MeSHDb resource ## filepath_hsa <- qr_hsa[[1]] ## db <- MeSHDbi::MeSHDb(filepath_hsa) ## hsamd <- meshdata(db, category='A', computeIC=T, database="gendoo") data(hsamd) meshSim("D000009", "D009130", semData=hsamd, measure="Resnik")## library(meshes) ## library(AnnotationHub) ## ah <- AnnotationHub() ## qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens")) ## ## inspect qr_hsa and select the organism-specific MeSHDb resource ## filepath_hsa <- qr_hsa[[1]] ## db <- MeSHDbi::MeSHDb(filepath_hsa) ## hsamd <- meshdata(db, category='A', computeIC=T, database="gendoo") data(hsamd) meshSim("D000009", "D009130", semData=hsamd, measure="Resnik")